<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="it">
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Scorciatoie nascoste</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="20"/>
        <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
        <translation>Queste scorciatoie predefinite saranno sovrascritte se assegnate ad altre azioni in Preferenze →Scorciatoie.</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Shortcut</source>
        <translation>Scorciatoia</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Action</source>
        <translation>Azione</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="44"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Close window or exit fullscreen mode</source>
        <translation>Chiudi finestra o esci da schermo intero</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="52"/>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Next image</source>
        <translation>Immagine prossima</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="60"/>
        <source>Space</source>
        <translation>Spazio</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="68"/>
        <source>End</source>
        <translation>Fine</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Last image</source>
        <translation>Ultima immagine</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="76"/>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Previous image</source>
        <translation>Immagine precedente</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="84"/>
        <source>Backspace</source>
        <translation>Backspace</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="92"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>First image</source>
        <translation>Prima immagine</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="94"/>
        <source>Start in fullscreen (can be useful with tiling window managers)</source>
        <translation>Avvia a schermo intero (potrebbe essere utile con gestori finestre tiling)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="102"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>Cattura schermata (non più supportato, usare Screengrab come alternativa)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>DIR</source>
        <translation>DIR</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>Cattura una schermata e salvala nella cartella senza mostrare l&apos;interfaccia grafica (non più supportato, usare screengrab come alternativa)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="117"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FILE1, FILE2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../upload/imageshackupload.cpp" line="50"/>
        <source>unknown error response</source>
        <translation>Errore sconosciuto</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>Errore sconosciuto</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>Errore sconosciuto</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>A simple and fast image viewer</source>
        <translation>Un visualizzatore immagini veloce e leggero</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Copyright (C) </source>
        <translation>Copyright (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>2013-2021</source>
        <translation>2013-2021</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>LXQt Project</source>
        <translation>LXQt Project</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>Development: </source>
        <translation>Sviluppo: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Author: </source>
        <translation>Autore: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="515"/>
        <source>Open File</source>
        <translation>Apri file</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>Image files (%1)</source>
        <translation>File immagini (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Open directory</source>
        <translation>Apri cartella</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Save File</source>
        <translation>Salva file</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (caricando...) - Visualizzatore immagini</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="845"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (caricamento non riuscito...) - Visualizzatore immagini</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="851"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Visualizzatore immagini</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="897"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Visualizzatore immagini</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1294"/>
        <source>Thumbnails</source>
        <translation>Miniature</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1389"/>
        <source>EXIF Data</source>
        <translation>Dati EXIF</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>&amp;Pulisci</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>Usa un tasto modificatore per cancellare una
scorciatoia in modalità di modifica.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="206"/>
        <source>Bottom</source>
        <translation>In basso</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="207"/>
        <source>Top</source>
        <translation>In alto</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="208"/>
        <source>Left</source>
        <translation>A sinistra</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="334"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Attenzione: Scorciatoia presente due volte! rilevata&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="351"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Scorciatoia già in uso - non applicata.&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>Impossibile salvare in questo formato!</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>Percorso:</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="52"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="53"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="54"/>
        <source>ImageShack</source>
        <translation>ImageShack</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Start</source>
        <translation>Avvio</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Stop</source>
        <translation>Ferma</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="143"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="150"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Visualizzatore immagini</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="204"/>
        <location filename="../mainwindow.ui" line="683"/>
        <source>Annotations Toolbar</source>
        <translation>Barra degli strumenti delle annotazioni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>&amp;About</source>
        <translation>&amp;Informazioni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Save &amp;As</source>
        <translation>Salva con &amp;nome</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>Zoom &amp;In</source>
        <translation>&amp;Ingrandisci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Rimpicciolisci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Copia negli appunti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Next File</source>
        <translation>File successivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Previous File</source>
        <translation>File precedente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>PgDown</source>
        <translation>Pagina giù</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation>Apri &amp;con...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recently Opened Files</source>
        <translation>File &amp;recenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Sorting</source>
        <translation>Ordinamento</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>Scorciatoie &amp;nascoste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="238"/>
        <source>&amp;Open…</source>
        <translation>&amp;Apri…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&amp;Reload File</source>
        <translation>&amp;Ricarica file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="352"/>
        <source>PgUp</source>
        <translation>Pagina su</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Original Size</source>
        <translation>Dimensioni originali</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>&amp;Fit</source>
        <translation>&amp;Adatta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;Ruota in senso orario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Ruota in &amp;senso antiorario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>P&amp;references</source>
        <translation>P&amp;referenze</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>&amp;Print</source>
        <translation>Stam&amp;pa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="425"/>
        <source>First File</source>
        <translation>Primo file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="437"/>
        <source>Last File</source>
        <translation>Ultimo file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>End</source>
        <translation>Fine</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nuova finestra</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="457"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Rispecchia &amp;orizzontalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="469"/>
        <source>Capture Screenshot</source>
        <translation>Cattura schermata</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>F&amp;ull Screen</source>
        <translation>&amp;Schermo intero</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>Flip &amp;Vertically</source>
        <translation>Rispecchia &amp;verticalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Incolla dagli appunti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Presentazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="518"/>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="521"/>
        <source>Del</source>
        <translation>Canc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="529"/>
        <source>Show Thumbnails</source>
        <translation>Mostra anteprime</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="532"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>File Properties</source>
        <translatorcomment>Übersetzung von &apos;file&apos; weggelassen, da redundant.</translatorcomment>
        <translation>Proprietà del file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Open &amp;Directory</source>
        <translation>Apri &amp;cartella</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="558"/>
        <source>Upload</source>
        <translation>Carica</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="561"/>
        <source>Upload the image</source>
        <translation>Carica l&apos;immagine</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>Show EXIF Data</source>
        <translation>Mostra data EXIF</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>No Tool</source>
        <translation>Nessuno strumento</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="587"/>
        <source>Deselect all drawing tools</source>
        <translation>Deseleziona tutti gli strumenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="599"/>
        <source>Draw Arrow</source>
        <translation>Disegna freccia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="602"/>
        <source>Draw an arrow</source>
        <translation>Disegna una freccia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="614"/>
        <source>Draw Rectangle</source>
        <translation>Disegna un rettangolo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Draw a hollow rectangle</source>
        <translation>Disegna un rettangolo vuoto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="629"/>
        <source>Draw Circle</source>
        <translation>Disegna un cerchio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="632"/>
        <source>Draw a hollow circle</source>
        <translation>Disegna un cerchio vuoto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="644"/>
        <source>Draw Number</source>
        <translation>Disegna un numero</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Draw incrementing numbers</source>
        <translation>Disegna numeri crescenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="655"/>
        <location filename="../mainwindow.ui" line="658"/>
        <source>Menubar</source>
        <translation>Barra dei menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <source>&amp;Main Toolbar</source>
        <translation>Barra degli &amp;strumenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <source>Main Toolbar</source>
        <translation>Barra degli strumenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>&amp;Barra degli strumenti delle annotazioni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="691"/>
        <location filename="../mainwindow.ui" line="694"/>
        <source>Show Outline</source>
        <translation>Mostra contorno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="697"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="705"/>
        <source>Copy Pa&amp;th</source>
        <translation>Copia &amp;percorso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <source>Copy path</source>
        <translation>Copia percorso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="716"/>
        <location filename="../mainwindow.ui" line="719"/>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="722"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="731"/>
        <source>Resize</source>
        <translation>Ridimensiona</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="739"/>
        <source>&amp;By File Name</source>
        <translation>Per &amp;nome file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="742"/>
        <source>By File Name</source>
        <translation>Per nome file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>By &amp;Modification Time</source>
        <translation>Per  &amp;data di modifica</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>By Modification Time</source>
        <translation>Per data di modifica</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="761"/>
        <source>By C&amp;reation Time</source>
        <translation>Per data di &amp;creazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="764"/>
        <source>By Creation Time</source>
        <translation>Per data di creazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="772"/>
        <source>By File &amp;Size</source>
        <translation>Per di&amp;mensione file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="775"/>
        <source>By File Size</source>
        <translation>Per dimensione file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="783"/>
        <source>By File &amp;Type</source>
        <translation>Per &amp;tipo file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="786"/>
        <source>By File Type</source>
        <translation>Per tipo file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Go</source>
        <translation>Vai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>&amp;View</source>
        <translation>&amp;Visualizza</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="145"/>
        <source>&amp;Edit</source>
        <translation>&amp;Modifica</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>Toolbar</source>
        <translation>Barra degli strumenti</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Preferenze</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Tema delle icone:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="53"/>
        <source>Thumbnailer file size limit:</source>
        <translation>Dimensione massima delle miniature:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="151"/>
        <source>Normal background color:</source>
        <translation>Colore sfondo:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="165"/>
        <source>Fullscreen background color:</source>
        <translation>Colore sfondo schermo intero:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Maximum number of recent files:</source>
        <translation>Numero massimo di file recenti:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="179"/>
        <source>Slide show interval (seconds):</source>
        <translation>Ritardo presentazione (secondi):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="193"/>
        <source>Show image outline by default</source>
        <translation>Mostra sempre il contorno dell&apos;immagine</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Show annotations toolbar by default</source>
        <translation>Mostra sempre la barra degli strumenti delle annotazioni</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>Fit images when navigating</source>
        <translation>Adatta immagini nella navigazione</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="60"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="76"/>
        <source>Thumbnail image dimensions:</source>
        <translation>Dimensione delle miniature:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="86"/>
        <source>Use system Trash (and do not prompt)</source>
        <translation>Usa cestino (senza conferma)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="103"/>
        <source>Show thumbnails dock by default</source>
        <translation>Mostra sempre la barra delle miniature</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="113"/>
        <source>Show Exif data dock by default</source>
        <translation>Mostra sempre il pannello con le data Exif</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="120"/>
        <source>Show menubar by default</source>
        <translation>Mostra sempre la barra del menu</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="127"/>
        <source>Show main toolbar by default</source>
        <translation>Mostra sempre la barra degli strumenti</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Image</source>
        <translation>Immagine</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="207"/>
        <source>Smooth images on zooming</source>
        <translation>Liscia immagini se ingranditi</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="215"/>
        <source>Shortcuts</source>
        <translation>Scorciatoie</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="234"/>
        <source>Action</source>
        <translation>Azione</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="239"/>
        <source>Shortcut</source>
        <translation>Scorciatoia</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="247"/>
        <source>Default</source>
        <translation>Ripristina</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Generali</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="989"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>Ridimensiona immagine</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>Larghezza</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>Altezza</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>Dimensione attuale:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>Dimensione nuova:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>Mantieni le proporzioni</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Schermata</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Cattura schermata</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Schermo intero</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Finestra attuale</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Area selezionata</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Includi cursore</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> sec</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Ritardo:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Includi cornice finestra</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Carica</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
</context>
</TS>
